from sklearn.preprocessing import LabelEncoder
import pandas as pd
import matplotlib.pyplot as plt


def rf_feat_importance(model, X, plot=False):
    '''
    Creates a dataframe of feature importances from the random forest model ( works also for catboost models)
    Parameters:
    X : the Dataframe used for training ( X_train )
    model : The trained Model
    plot : Whether to plot the feature importance ( default : False)
    Returns:
    pd.DataFrame:Feature Importance DataFrame
    '''
    fi = pd.DataFrame({'cols': X.columns, 'imp': model.feature_importances_}
                      ).sort_values('imp', ascending=False)
    if plot:
        fi[:20].plot.barh(x="cols", y="imp", figsize=(10, 10))
        plt.show()
    return fi



from sklearn.preprocessing import LabelEncoder
import pandas as pd
import matplotlib.pyplot as plt


class MultiColumnLabelEncoder:
    '''
    A Multi Column Label Encoder to use for Pandas dataframe based on Sklearn LabelEncoder
    example usage : 
    me = MultiColumnLabelEncoder()
    X_train_transformed = me.fit_transform(X_train)
    me.transform(X_test)
    me.inverse_transform(X_train_transformed)
    '''

    def __init__(self):
        self.transformers = {}

    def fit_transform(self, dframe):
        '''
        Fits and transforms the dataframe using LabelEncoder
        Parameters:
        dframe : DataFrame to transform

        Returns:
        pd.DataFrame:Encoded Dataframe

        '''
        data = {}
        for column in dframe.columns:
            self.transformers[column] = LabelEncoder()
            data[column] = self.transformers[column].fit_transform(
                dframe[column])
        return pd.DataFrame(data)

    def transform(self, dframe):
        '''
        Transforms the dataframe using LabelEncoder
        Parameters:
        dframe : DataFrame to transform

        Returns:
        pd.DataFrame:Encoded Dataframe

        '''
        data = {}
        for column in dframe.columns:
            data[column] = self.transformers[column].transform(dframe[column])
        return pd.DataFrame(data)

    def inverse_transform(self, dframe):
        '''
        Returns the original Data Frame from the encoded one .
        Parameters:
        dframe : Transformed DataFrame

        Returns:
        pd.DataFrame:Original Dataframe

        '''
        data = {}
        for column in dframe.columns:
            data[column] = self.transformers[column].inverse_transform(
                dframe[column])
        return pd.DataFrame(data)


def missing_values(df, plot=False):
    '''
    Creates a Dataframe with the percentage of missing values for each column
    Parameters:
    df : Input DataFrame
    plot : Whether to plot the missing values percentages ( default : False)

    Returns:
    pd.DataFrame: Missing Values DataFrame
    '''
    percent_missing = df.isnull().sum() * 100 / len(df)
    missing_value_df = pd.DataFrame({'percent_missing': percent_missing})
    if plot:
        missing_value_df['percent_missing'][:20].plot.barh()
        plt.show()
    return missing_value_df



import sys

def main(args=None):
	"""The main routine."""
	if args is None:
		args = sys.argv[1:]

	print("This is the main routine.")
	print("It should do something interesting.")
	
	print( "This is the name of the script: ", sys.argv[0])
	print( "Number of arguments: ", len(sys.argv))
	print( "The arguments are: " , str(sys.argv))	

	# Do argument parsing here with argparse

if __name__ == "__main__":
	main()



from setuptools import setup, find_packages

version = open('VERSION').read().strip()
license = open('LICENSE').read().strip()

setup(
    name='ez-ml',
    version=version,
    license=license,
    author='Ghazi Ben Dahmen',
    author_email='ghazi.ben.dahmen3@gmail.com',
    url='http://www.github.com/ghazibendahmen/ez-ml',
    description='Most useful ML lib',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        'pandas',
        'sklearn',
        'matplotlib'
    ],
    entry_points={
        'console_scripts': [
            'ezml = ezml.__main__:main',
        ]
    }
)
